@@ -7,6 +7,11 @@ mod object;
 mod string;
 mod symbol;
 
+#[cfg(feature = "array-buffer")]
+mod array_buffer;
+#[cfg(feature = "array-buffer")]
+mod typed_array;
+
 use crate::{qjs, Ctx, Error, Result};
 
 pub use module::{Created, Evaluated, Loaded, Module, ModuleDef, ModuleLoadFn, Native, Script};
@@ -23,6 +28,11 @@ pub use object::{Filter, Object, ObjectDef};
 pub use string::String;
 pub use symbol::Symbol;
 
+#[cfg(feature = "array-buffer")]
+pub use array_buffer::ArrayBuffer;
+#[cfg(feature = "array-buffer")]
+pub use typed_array::TypedArray;
+
 #[cfg(feature = "futures")]
 pub use function::Async;
 
@@ -336,6 +346,12 @@ impl<'js> Value<'js> {
     }
 }
 
+impl<'js> AsRef<Value<'js>> for Value<'js> {
+    fn as_ref(&self) -> &Value<'js> {
+        self
+    }
+}
+
 macro_rules! type_impls {
     // type: name => tag
     ($($type:ident: $name:ident => $tag:ident,)*) => {
