@@ -226,6 +226,14 @@ impl<'js> Object<'js> {
         }
     }
 
+    /// Check instance of object
+    pub fn is_instance_of(&self, class: impl AsRef<Value<'js>>) -> bool {
+        let class = class.as_ref();
+        0 != unsafe {
+            qjs::JS_IsInstanceOf(self.0.ctx.ctx, self.0.as_js_value(), class.as_js_value())
+        }
+    }
+
     /// Convert into a function
     pub fn into_function(self) -> Option<Function<'js>> {
         if self.is_function() {
@@ -266,24 +274,28 @@ impl Filter {
     }
 
     /// Include string properties
+    #[must_use]
     pub fn string(mut self) -> Self {
         self.flags |= qjs::JS_GPN_STRING_MASK as qjs::c_int;
         self
     }
 
     /// Include symbol properties
+    #[must_use]
     pub fn symbol(mut self) -> Self {
         self.flags |= qjs::JS_GPN_SYMBOL_MASK as qjs::c_int;
         self
     }
 
     /// Include private properties
+    #[must_use]
     pub fn private(mut self) -> Self {
         self.flags |= qjs::JS_GPN_PRIVATE_MASK as qjs::c_int;
         self
     }
 
     /// Include only enumerable properties
+    #[must_use]
     pub fn enum_only(mut self) -> Self {
         self.flags |= qjs::JS_GPN_ENUM_ONLY as qjs::c_int;
         self
